@@ -12,6 +12,8 @@ This is the complete API reference:
    colors
 """
 
-__version__ = "0.1.2"
+__version__ = "0.2.1"
 
+from . import _configure_external  # noqa
 from ._core import colors, logger  # noqa
+from ._python_version import py_version_warning  # noqa
